@@ -29,6 +29,7 @@ use crate::core::{EmptyResult, GenericResult};
 use crate::currency::{Cash, CashAssets, MultiCurrencyCashAccount};
 use crate::currency::converter::CurrencyConverter;
 use crate::formatting;
+use crate::instruments::{InstrumentInternalIds, InstrumentInfo};
 use crate::localities;
 use crate::quotes::Quotes;
 use crate::taxes::TaxRemapping;
@@ -77,16 +78,20 @@ pub struct BrokerStatement {
     pub stock_splits: StockSplitController,
 
     pub open_positions: HashMap<String, Decimal>,
-    instrument_names: HashMap<String, String>,
+    pub instrument_info: InstrumentInfo,
 }
 
 impl BrokerStatement {
     pub fn read(
         broker: BrokerInfo, statement_dir_path: &str,
-        symbol_remapping: &HashMap<String, String>, instrument_names: &HashMap<String, String>,
-        tax_remapping: TaxRemapping, corporate_actions: &[CorporateAction], strictness: ReadingStrictness,
+        symbol_remapping: &HashMap<String, String>, instrument_internal_ids: &InstrumentInternalIds,
+        instrument_names: &HashMap<String, String>, tax_remapping: TaxRemapping,
+        corporate_actions: &[CorporateAction], strictness: ReadingStrictness,
     ) -> GenericResult<BrokerStatement> {
-        let mut statements = reader::read(broker.type_, statement_dir_path, tax_remapping, strictness)?;
+        let jurisdiction = broker.type_.jurisdiction();
+
+        let mut statements = reader::read(
+            broker.type_, statement_dir_path, instrument_internal_ids, tax_remapping, strictness)?;
         statements.sort_by(|a, b| a.period.unwrap().0.cmp(&b.period.unwrap().0));
 
         let last_index = statements.len() - 1;
@@ -114,8 +119,11 @@ impl BrokerStatement {
         }
 
         for (dividend_id, accruals) in dividend_accruals {
+            let taxation_type = statement.instrument_info.get_issuer_taxation_type(
+                &dividend_id.issuer, jurisdiction)?;
+
             let (dividend, cash_flows) = process_dividend_accruals(
-                dividend_id, accruals, &mut tax_accruals, true)?;
+                dividend_id, taxation_type, accruals, &mut tax_accruals, true)?;
 
             if let Some(dividend) = dividend {
                 statement.dividends.push(dividend);
@@ -148,9 +156,11 @@ impl BrokerStatement {
         }
 
         statement.corporate_actions.extend(corporate_actions.iter().cloned());
-        statement.instrument_names.extend(instrument_names.iter().map(|(symbol, name)| {
-            (symbol.clone(), name.clone())
-        }));
+
+        for (symbol, name) in instrument_names {
+            statement.instrument_info.get_or_add(symbol).set_name(name);
+        }
+
         statement.validate()?;
 
         process_corporate_actions(&mut statement)?;
@@ -193,7 +203,7 @@ impl BrokerStatement {
             stock_splits: StockSplitController::default(),
 
             open_positions: HashMap::new(),
-            instrument_names: HashMap::new(),
+            instrument_info: InstrumentInfo::new(),
         })
     }
 
@@ -232,14 +242,6 @@ impl BrokerStatement {
         Ok(())
     }
 
-    pub fn get_instrument_name(&self, symbol: &str) -> String {
-        if let Some(name) = self.instrument_names.get(symbol) {
-            format!("{} ({})", name, symbol)
-        } else {
-            symbol.to_owned()
-        }
-    }
-
     pub fn batch_quotes(&self, quotes: &Quotes) -> EmptyResult {
         for symbol in self.open_positions.keys() {
             quotes.batch(symbol)?;
@@ -410,16 +412,11 @@ impl BrokerStatement {
 
         for (master_symbol, slave_symbols) in symbols_to_merge {
             for slave_symbol in slave_symbols {
+                self.instrument_info.merge_symbols(master_symbol, slave_symbol, strict)?;
                 symbol_mapping.insert(slave_symbol, master_symbol);
             }
         }
 
-        for &symbol in symbol_mapping.keys() {
-            if strict && self.instrument_names.remove(symbol).is_none() {
-                return Err!("The broker statement has no any activity for {:?} symbol", symbol);
-            }
-        }
-
         for stock_buy in &mut self.stock_buys {
             if let Some(&symbol) = symbol_mapping.get(&stock_buy.symbol) {
                 stock_buy.symbol = symbol.clone();
@@ -463,11 +460,10 @@ impl BrokerStatement {
         self.forex_trades.extend(statement.forex_trades.into_iter());
         self.stock_buys.extend(statement.stock_buys.into_iter());
         self.stock_sells.extend(statement.stock_sells.into_iter());
-        self.dividends.extend(statement.dividends.into_iter());
 
         self.corporate_actions.extend(statement.corporate_actions.into_iter());
         self.open_positions = statement.open_positions;
-        self.instrument_names.extend(statement.instrument_names.into_iter());
+        self.instrument_info.merge(statement.instrument_info);
 
         Ok(())
     }
@@ -500,7 +496,7 @@ impl BrokerStatement {
         };
 
         if remapping {
-            if self.open_positions.contains_key(new_symbol) || self.instrument_names.contains_key(new_symbol) {
+            if self.open_positions.contains_key(new_symbol) {
                 return Err!("The portfolio already has {} symbol", new_symbol);
             }
 
@@ -508,9 +504,7 @@ impl BrokerStatement {
                 self.open_positions.insert(new_symbol.to_owned(), quantity);
             }
 
-            if let Some(name) = self.instrument_names.remove(symbol) {
-                self.instrument_names.insert(new_symbol.to_owned(), name);
-            }
+            self.instrument_info.remap(symbol, new_symbol)?;
         } else {
             self.stock_splits.rename(symbol, new_symbol)?;
         }
