@@ -4,11 +4,12 @@ use std::collections::hash_map::Entry;
 use crate::core::{EmptyResult, GenericResult};
 use crate::currency::{Cash, CashAssets, MultiCurrencyCashAccount};
 use crate::formatting;
+use crate::instruments::InstrumentInfo;
 use crate::types::{Date, Decimal};
 use crate::util::{DecimalRestrictions, validate_named_decimal};
 
 use super::corporate_actions::CorporateAction;
-use super::dividends::{Dividend, DividendId, DividendAccruals};
+use super::dividends::{DividendId, DividendAccruals};
 use super::fees::Fee;
 use super::interest::IdleCashInterest;
 use super::trades::{ForexTrade, StockBuy, StockSell};
@@ -26,17 +27,16 @@ pub struct PartialBrokerStatement {
     pub forex_trades: Vec<ForexTrade>,
     pub stock_buys: Vec<StockBuy>,
     pub stock_sells: Vec<StockSell>,
-    pub dividends: Vec<Dividend>,
 
-    pub instrument_names: HashMap<String, String>,
-    pub corporate_actions: Vec<CorporateAction>,
     pub dividend_accruals: HashMap<DividendId, DividendAccruals>,
     pub tax_accruals: HashMap<TaxId, TaxAccruals>,
+    pub corporate_actions: Vec<CorporateAction>,
 
     // Please note that some brokers (Firstrade) provide this information only for the last
     // statement (current date).
     pub assets: NetAssets,
     pub open_positions: HashMap<String, Decimal>,
+    pub instrument_info: InstrumentInfo,
 }
 
 pub struct NetAssets {
@@ -58,12 +58,10 @@ impl PartialBrokerStatement {
             forex_trades: Vec::new(),
             stock_buys: Vec::new(),
             stock_sells: Vec::new(),
-            dividends: Vec::new(),
 
-            instrument_names: HashMap::new(),
-            corporate_actions: Vec::new(),
             dividend_accruals: HashMap::new(),
             tax_accruals: HashMap::new(),
+            corporate_actions: Vec::new(),
 
             assets: NetAssets {
                 cash: if zero_cash_assets {
@@ -74,6 +72,7 @@ impl PartialBrokerStatement {
                 other: None
             },
             open_positions: HashMap::new(),
+            instrument_info: InstrumentInfo::new(),
         }
     }
 
