@@ -26,8 +26,9 @@ pub fn sync(config: &Config, portfolio_name: &str) -> GenericResult<TelemetryRec
     let database = db::connect(&config.db_path)?;
 
     let statement = BrokerStatement::read(
-        broker, &portfolio.statements, &portfolio.symbol_remapping, &portfolio.instrument_names,
-        portfolio.get_tax_remapping()?, &portfolio.corporate_actions, ReadingStrictness::empty())?;
+        broker, &portfolio.statements, &portfolio.symbol_remapping, &portfolio.instrument_internal_ids,
+        &portfolio.instrument_names, portfolio.get_tax_remapping()?, &portfolio.corporate_actions,
+        ReadingStrictness::empty())?;
     statement.check_date();
 
     let assets = Assets::new(statement.cash_assets, statement.open_positions);
